[teiid-commits] teiid SVN: r1567 - in trunk/test-integration/db/src/main/java/org/teiid/test/framework: query and 1 other directories.

teiid-commits at lists.jboss.org teiid-commits at lists.jboss.org
Mon Nov 16 17:03:56 EST 2009


Author: vhalbert at redhat.com
Date: 2009-11-16 17:03:56 -0500 (Mon, 16 Nov 2009)
New Revision: 1567

Modified:
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/TransactionContainer.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/AbstractQueryTransactionTest.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/QueryExecution.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/JNDITransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/LocalTransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OffWrapTransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OnWrapTransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OptimisticWrapTransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/PessimisticWrapTransaction.java
   trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/XATransaction.java
Log:
Teiid 773 -  renamed interface so that it would collide with the tests that are suppose to run

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/TransactionContainer.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/TransactionContainer.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/TransactionContainer.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -48,13 +48,13 @@
 	this.getConnectionStrategy().getEnvironment().setProperty(key, value);
     }
 
-    protected void before(TransactionQueryTest test) {
+    protected void before(TransactionQueryTestCase test) {
     }
 
-    protected void after(TransactionQueryTest test) {
+    protected void after(TransactionQueryTestCase test) {
     }
 
-    public void runTransaction(TransactionQueryTest test) {
+    public void runTransaction(TransactionQueryTestCase test) {
 
 	this.testClassName = StringUtil.getLastToken(test.getClass().getName(),
 		".");
@@ -94,7 +94,7 @@
 
     }
 
-    protected void runTest(TransactionQueryTest test) {
+    protected void runTest(TransactionQueryTestCase test) {
 	debug("Start runTest: " + test.getTestName());
 
 	try {

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/AbstractQueryTransactionTest.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/QueryExecution.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/QueryExecution.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -13,9 +13,10 @@
  *
  */
 public class QueryExecution extends AbstractQueryTest {
-	
+    
 	public QueryExecution(Connection conn) {
 		super(conn);
 	}
+	
 
 }

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/JNDITransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/JNDITransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/JNDITransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -7,9 +7,8 @@
 import javax.naming.InitialContext;
 import javax.transaction.UserTransaction;
 
-import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.exception.TransactionRuntimeException;
 
@@ -19,11 +18,12 @@
 public class JNDITransaction extends TransactionContainer {
     UserTransaction userTxn = null;
     
-//    public JNDITransaction(ConfigPropertyLoader config) {
-//        super(config);
-//    }
     
-    protected void before(TransactionQueryTest test) {
+    public JNDITransaction() {
+	super();
+    }
+    
+    protected void before(TransactionQueryTestCase test) {
         if (this.props.getProperty(CONNECTION_STRATEGY_PROPS.JNDINAME_USERTXN) == null) {
             throw new TransactionRuntimeException("No JNDI name found for the User Transaction to look up in application server");
         }
@@ -39,7 +39,7 @@
         }        
     }
     
-    protected void after(TransactionQueryTest test) {
+    protected void after(TransactionQueryTestCase test) {
         try {
             if (this.userTxn != null) {
                 if (test.rollbackAllways()|| test.exceptionOccurred()) {

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/LocalTransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/LocalTransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/LocalTransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -9,7 +9,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.ConfigPropertyNames.TXN_AUTO_WRAP_OPTIONS;
 import org.teiid.test.framework.exception.TransactionRuntimeException;
@@ -23,7 +23,7 @@
     public LocalTransaction() {
 	super();
     }
-    protected void before(TransactionQueryTest test) {
+    protected void before(TransactionQueryTestCase test) {
 	this.setEnvironmentProperty(CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP, TXN_AUTO_WRAP_OPTIONS.AUTO_WRAP_OFF);
 	
         try {
@@ -34,7 +34,7 @@
         }        
     }
     
-    protected void after(TransactionQueryTest test) {
+    protected void after(TransactionQueryTestCase test) {
     	boolean exception = false;
         try {            
             if (test.rollbackAllways()|| test.exceptionOccurred()) {

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OffWrapTransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OffWrapTransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OffWrapTransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -6,7 +6,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.ConfigPropertyNames.TXN_AUTO_WRAP_OPTIONS;
 
@@ -23,13 +23,13 @@
 	super();
     }
     
-    public void before(TransactionQueryTest test) {
+    public void before(TransactionQueryTestCase test) {
 	this.setEnvironmentProperty(CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP, TXN_AUTO_WRAP_OPTIONS.AUTO_WRAP_OFF);
 
         
     }
     
-    public void after(TransactionQueryTest test) {
+    public void after(TransactionQueryTestCase test) {
 
     }
 }

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OnWrapTransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OnWrapTransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OnWrapTransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -6,7 +6,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.ConfigPropertyNames.TXN_AUTO_WRAP_OPTIONS;
 
@@ -21,13 +21,13 @@
 	super();
     }
         
-    public void before(TransactionQueryTest test) {
+    public void before(TransactionQueryTestCase test) {
 	this.setEnvironmentProperty(CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP, TXN_AUTO_WRAP_OPTIONS.AUTO_WRAP_ON);
 
         
     }
     
-    public void after(TransactionQueryTest test) {
+    public void after(TransactionQueryTestCase test) {
 
     }
 }

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OptimisticWrapTransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OptimisticWrapTransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/OptimisticWrapTransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -6,7 +6,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.ConfigPropertyNames.TXN_AUTO_WRAP_OPTIONS;
 
@@ -21,12 +21,12 @@
 	super();
     }
     
-    public void before(TransactionQueryTest test) {
+    public void before(TransactionQueryTestCase test) {
 	this.setEnvironmentProperty(CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP, TXN_AUTO_WRAP_OPTIONS.AUTO_WRAP_OPTIMISTIC);
 
     }
     
-    public void after(TransactionQueryTest test) {
+    public void after(TransactionQueryTestCase test) {
 
     }
 }

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/PessimisticWrapTransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/PessimisticWrapTransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/PessimisticWrapTransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -6,7 +6,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.ConfigPropertyNames.TXN_AUTO_WRAP_OPTIONS;
 
@@ -21,12 +21,12 @@
 	super();
     }
     
-    public void before(TransactionQueryTest test) {
+    public void before(TransactionQueryTestCase test) {
 	this.setEnvironmentProperty(CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP, TXN_AUTO_WRAP_OPTIONS.AUTO_WRAP_PESSIMISTIC);
 
     }
     
-    public void after(TransactionQueryTest test) {
+    public void after(TransactionQueryTestCase test) {
 
     }
     

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/XATransaction.java
===================================================================
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/XATransaction.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/transaction/XATransaction.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -11,7 +11,7 @@
 
 import org.teiid.test.framework.ConfigPropertyLoader;
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.exception.QueryTestFailedException;
 import org.teiid.test.framework.exception.TransactionRuntimeException;
 
@@ -25,7 +25,7 @@
 		super();
 	}
         
-    protected void before(TransactionQueryTest test) {
+    protected void before(TransactionQueryTestCase test) {
         try {          
         	xid = createXid();
         	XAResource xaResource = getXAConnection().getXAResource();
@@ -46,7 +46,7 @@
 		return new MMXid(0, gid, bid);
 	}
     
-    protected void after(TransactionQueryTest test) {
+    protected void after(TransactionQueryTestCase test) {
         boolean delistSuccessful = false;
         boolean commit = false;
         



More information about the teiid-commits mailing list
--- trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/AbstractQueryTransactionTest.java	2009-11-16 21:08:22 UTC (rev 1566)
+++ trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/AbstractQueryTransactionTest.java	2009-11-16 22:03:56 UTC (rev 1567)
@@ -12,7 +12,7 @@
 import javax.sql.XAConnection;
 
 import org.teiid.test.framework.TransactionContainer;
-import org.teiid.test.framework.TransactionQueryTest;
+import org.teiid.test.framework.TransactionQueryTestCase;
 import org.teiid.test.framework.ConfigPropertyNames.CONNECTION_STRATEGY_PROPS;
 import org.teiid.test.framework.connection.ConnectionStrategy;
 import org.teiid.test.framework.datasource.DataStore;
@@ -22,7 +22,7 @@
 
 /**
  * The AbstractQueryTransactionTest is the base implementation for the
  * {@link TransactionQueryTest}. This provides the default logic for perform a testcase.
  * The only method to implement in order to perform a basic, single datasource, test
  * is the {@link #testCase()} method.
  * 
@@ -43,7 +43,7 @@
  * 
  */
 public abstract class AbstractQueryTransactionTest extends  com.metamatrix.jdbc.api.AbstractQueryTest
-	implements TransactionQueryTest {
+	implements TransactionQueryTestCase {
     
     private static boolean initialized = false;
 
@@ -97,7 +97,8 @@
 			    CONNECTION_STRATEGY_PROPS.TXN_AUTO_WRAP,
 			    txnautowrap);
 		    
-		    this.print("TransactionAutoWrap = " + txnautowrap);
+		   
+//		    this.print("TransactionAutoWrap = " + txnautowrap);
 		}
 		
 		String fetchSizeStr = executionProperties
@@ -239,7 +240,7 @@
      * At end of each test, perform any cleanup that your test requires. Note:
      * Do not cleanup any connections by calling {@link ConnectionStrategy#shutdown()}. 
      * That is performed by the
-     * {@link TransactionContainer#runTransaction(TransactionQueryTest)} at the
+     * {@link TransactionContainer#runTransaction(TransactionQueryTestCase)} at the
      * end of the test.
      */
     public void cleanup() {
@@ -22,7 +22,7 @@
 /**
  * The AbstractQueryTransactionTest is the base implementation for the
- * {@link TransactionQueryTest}. This provides the default logic for perform a testcase.
+ * {@link TransactionQueryTestCase}. This provides the default logic for perform a testcase.
  * The only method to implement in order to perform a basic, single datasource, test
  * is the {@link #testCase()} method.

Modified: trunk/test-integration/db/src/main/java/org/teiid/test/framework/query/QueryExecution.java
===================================================================